package main

import (
	"flag"
	"fmt"
	mapset "github.com/deckarep/golang-set"
	"pestiot/solutions"
	"pestiot/utils"
	"strings"
)

// 命令行接收参数
var (
	provIds    string
	beginDate  string
	endDate    string
	devIds     string
	solution   string
	mentioneds string
)

// 获取命令行参数
func getCmdParams() bool {
	flag.StringVar(&provIds, "provIds", "", "省份编号(必填)(e.g., 650000,340000)")
	flag.StringVar(&beginDate, "beginDate", "", "开始时间(必填)(e.g., 2022-07-01)")
	flag.StringVar(&endDate, "endDate", "", "结束时间(必填)(e.g., 2022-09-30)")
	flag.StringVar(&devIds, "devIds", "", "设备编号(可选)(e.g., 129301230102,12039912093,21399422244)")
	flag.StringVar(&solution, "solution", "", "解决方案(必填)(e.g., 01)\n01 计算设备可用率\n02 灯诱及性诱日统计")
	flag.StringVar(&mentioneds, "mentioneds", "", "消息提醒人员(可选)(e.g., gpguo@jinhetech.com,eszhong@jinhetech.com)")
	flag.Parse()
	if provIds == "" || beginDate == "" || endDate == "" || solution == "" {
		fmt.Println("必要参数缺失,请使用 -help 命令查看入参！")
		return false
	} else {
		return true
	}
}

func main() {
	var versionCode int32 = 0
	utils.CheckUpdate(versionCode)

	if !getCmdParams() {
		return
	}

	devSet := mapset.NewSet()
	if devIds != "" {
		for _, v := range strings.Split(devIds, ",") {
			devSet.Add(v)
		}
	}
	var mentionedList []string
	if mentioneds != "" {
		for _, v := range strings.Split(mentioneds, ",") {
			mentionedList = append(mentionedList, v)
		}
	}
	for _, provId := range strings.Split(provIds, ",") {
		fmt.Println(provId)
		var filepath, msg string
		if solution == "01" { // 计算设备可用率
			filepath, msg = solutions.CountEquipmentAvailability(provId, beginDate, endDate, devSet)
		} else if solution == "02" {
			filepath, msg = solutions.LightAndSexLureStatistics(provId, beginDate, endDate)
		}
		if filepath != "" {
			utils.WechatFileUpload(filepath, msg, &mentionedList, nil)
		}
	}
}
